==> haskell-chell-quickcheck-0.2.5.3-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chell-quickcheck
version:              0.2.5.3
visibility:           public
id:                   chell-quickcheck-0.2.5.3-4uZSlWs113l6Loa9BV5WjN
key:                  chell-quickcheck-0.2.5.3-4uZSlWs113l6Loa9BV5WjN
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for the Chell testing library
description:
    QuickCheck support for the <https://hackage.haskell.org/package/chell Chell> testing library.

category:             Testing
abi:                  dd04610b63783cc68fd19d98d3e476f3
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.0.2/site-local/chell-quickcheck-0.2.5.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/chell-quickcheck-0.2.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.3-4uZSlWs113l6Loa9BV5WjN
depends:
    QuickCheck-2.14.2-50g6nvTiNE5CM6werdwjjj base-4.15.1.0
    chell-0.5.0.1-4gZNMFwXh1YCUpg4omSyNb
    random-1.2.1.1-C8aN1mO2C5BFfFmB9GY7Ok

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-quickcheck-0.2.5.3-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chell-quickcheck
version:              0.2.5.3
visibility:           public
id:                   chell-quickcheck-0.2.5.3-Dt1KAkM8ghq5wkvCIKfLw3
key:                  chell-quickcheck-0.2.5.3-Dt1KAkM8ghq5wkvCIKfLw3
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for the Chell testing library
description:
    QuickCheck support for the <https://hackage.haskell.org/package/chell Chell> testing library.

category:             Testing
abi:                  3678ffb99ced14038117d1b3dc6e47cd
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.0.2/site-local/chell-quickcheck-0.2.5.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/chell-quickcheck-0.2.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.3-Dt1KAkM8ghq5wkvCIKfLw3
depends:
    QuickCheck-2.14.2-CWXi9Q1t8724ceglmst3lc base-4.15.1.0
    chell-0.5.0.1-4H8lklGweTg4HTmUt5qUN5
    random-1.2.1.1-KJ0FCJNKSsMBe9MmB5vC8X

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
